@@ -1,4 +1,3 @@
-from logging import ERROR
 import os
 import json
 import httpx
@@ -20,7 +19,7 @@ OCR_URL = "https://ke.study.163.com/code/ocrTrans"
 # ] = "tYwB%2FcQm2vlyCP1oP%2FRujcnfAMlAJ9ET8JZgyPzHchScEvbrs%2BuXh5XOk78v%2FGS91eloNmbyH3TmBKqtY6EyhqFW%2F%2FKZPfjA4clnffrfjFU%3D"
 
 
-class ReqAdapter:
+class ReqBuilder:
     @property
     def use_sdk(self):
         return self.appkey and self.appsecret
@@ -77,8 +76,8 @@ class ReqAdapter:
         return res
 
 
-trans_req = ReqAdapter("trans")
-ocr_req = ReqAdapter("ocr")
+trans_req = ReqBuilder("trans")
+ocr_req = ReqBuilder("ocr")
 
 
 def translate_post(q: str, **kwargs):
